@@ -524,10 +524,11 @@ class Server(object):
             try:
                 # iterate over the current clients
                 for s in self.sockets.copy().values():
-                    if s.closed:
-                        continue
-                    s.check_ping_timeout()
+                    if not s.closing and not s.closed:
+                        s.check_ping_timeout()
                     self.sleep(sleep_interval)
+            except (SystemExit, KeyboardInterrupt):
+                break
             except:
                 # an unexpected exception has occurred, log it and continue
                 self.logger.exception('service task exception')
